@@ -9,7 +9,7 @@ ScrollArea class to manage scrolling in menu.
 License:
 -------------------------------------------------------------------------------
 The MIT License (MIT)
-Copyright 2017-2020 Pablo Pizarro R. @ppizarror
+Copyright 2017-2021 Pablo Pizarro R. @ppizarror
 
 Permission is hereby granted, free of charge, to any person obtaining a
 copy of this software and associated documentation files (the "Software"),
@@ -92,7 +92,7 @@ class ScrollArea(object):
                  shadow_color=(0, 0, 0),
                  shadow_offset=2,
                  shadow_position=_locals.POSITION_SOUTHEAST,
-                 world=None,
+                 world=None
                  ):
         assert isinstance(area_width, (int, float))
         assert isinstance(area_height, (int, float))
@@ -132,24 +132,32 @@ class ScrollArea(object):
         for pos in self._scrollbar_positions:  # type:str
             assert_position(pos)
             if pos == _locals.POSITION_EAST or pos == _locals.POSITION_WEST:
-                sbar = ScrollBar(self._view_rect.height, (0, max(1, self.get_hidden_height())),
-                                 orientation=_locals.ORIENTATION_VERTICAL,
-                                 slider_pad=scrollbar_slider_pad,
-                                 slider_color=scrollbar_slider_color,
-                                 page_ctrl_thick=scrollbar_thick,
-                                 page_ctrl_color=scrollbar_color,
-                                 onchange=self._on_vertical_scroll)
+                sbar = ScrollBar(
+                    length=self._view_rect.height,
+                    values_range=(0, max(1, self.get_hidden_height())),
+                    orientation=_locals.ORIENTATION_VERTICAL,
+                    slider_pad=scrollbar_slider_pad,
+                    slider_color=scrollbar_slider_color,
+                    page_ctrl_thick=scrollbar_thick,
+                    page_ctrl_color=scrollbar_color,
+                    onchange=self._on_vertical_scroll
+                )
             else:
-                sbar = ScrollBar(self._view_rect.width, (0, max(1, self.get_hidden_width())),
-                                 slider_pad=scrollbar_slider_pad,
-                                 slider_color=scrollbar_slider_color,
-                                 page_ctrl_thick=scrollbar_thick,
-                                 page_ctrl_color=scrollbar_color,
-                                 onchange=self._on_horizontal_scroll)
-            sbar.set_shadow(enabled=shadow,
-                            color=shadow_color,
-                            position=shadow_position,
-                            offset=shadow_offset)
+                sbar = ScrollBar(
+                    length=self._view_rect.width,
+                    values_range=(0, max(1, self.get_hidden_width())),
+                    slider_pad=scrollbar_slider_pad,
+                    slider_color=scrollbar_slider_color,
+                    page_ctrl_thick=scrollbar_thick,
+                    page_ctrl_color=scrollbar_color,
+                    onchange=self._on_horizontal_scroll
+                )
+            sbar.set_shadow(
+                enabled=shadow,
+                color=shadow_color,
+                position=shadow_position,
+                offset=shadow_offset
+            )
             sbar.set_controls(joystick=False)
 
             self._scrollbars.append(sbar)
@@ -561,7 +569,9 @@ class ScrollArea(object):
         :return: True if collide
         :rtype: bool
         """
-        if event.type == pygame.FINGERDOWN or event.type == pygame.FINGERUP or event.type == pygame.FINGERMOTION:
+        if hasattr(pygame, 'FINGERDOWN') and (
+                event.type == pygame.FINGERDOWN or event.type == pygame.FINGERUP or
+                event.type == pygame.FINGERMOTION):
             display_size = self._menu.get_window_size()
             finger_pos = (event.x * display_size[0], event.y * display_size[1])
             return self.to_real_position(widget.get_rect()).collidepoint(finger_pos)
