@@ -9,7 +9,7 @@ Shows scroll area widget usage.
 License:
 -------------------------------------------------------------------------------
 The MIT License (MIT)
-Copyright 2017-2020 Pablo Pizarro R. @ppizarror
+Copyright 2017-2021 Pablo Pizarro R. @ppizarror
 
 Permission is hereby granted, free of charge, to any person obtaining a
 copy of this software and associated documentation files (the "Software"),
@@ -173,10 +173,11 @@ def main(test=False):
         # Paint background
         screen.fill(COLOR_BACKGROUND)
 
-        pygame.draw.rect(screen,
-                         (20, 89, 20),
-                         area.get_rect().inflate(20, 20),  # Inflate to see area overflow in case of bug
-                         )
+        pygame.draw.rect(
+            screen,
+            (20, 89, 20),
+            area.get_rect().inflate(20, 20),  # Inflate to see area overflow in case of bug
+        )
 
         # Application events
         events = pygame.event.get()
