@@ -38,7 +38,7 @@ class LeftArrowSelection(ArrowSelection):
     Widget selection left arrow class.
     Creates an arrow to the left of the selected menu item.
 
-    :param arrow_size: Size of arrow on x,y axis (width, height)
+    :param arrow_size: Size of arrow on *(x,y)* axis *(width,height)*
     :type arrow_size: tuple, list
     :param arrow_right_margin: Distance from the arrow to the widget
     :type arrow_right_margin: int, float
